@@ -16,7 +16,11 @@
 
 mod compatibility;
 mod examples;
+pub mod decision_logic;
+pub mod decision_tables;
+pub mod input_data;
+pub mod item_definition;
 
 pub use compatibility::*;
 pub use examples::valid::*;
-pub use examples::*;
+pub use examples::*;
\ No newline at end of file
